Struct KState
Source pub struct KState {Show 13 fields
pub devs: Devs,
pub vdevs: VDevs,
pub sys: Sys,
pub mnt: Mounts,
pub net: Net,
pub ipc: Ipc,
pub sched: Sched,
pub mm: Mm,
pub irq: Irq,
pub time: Time,
pub cpu: Cpu,
pub fs: Fs,
pub procs: Procs,
}
The central kernel state aggregate; one field per OS subsystem domain.
Return a 'static reference to the global kernel state.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.